libpysal write that "block contiguity structures are relevant when defining neighbor relations based on membership in a regime. For example, all counties belonging to the same state could be defined as neighbors, in an analysis of all counties in the US."
Source: libpysal
Usage
st_block_nb(regime, id = seq_along(regime), diag = FALSE)
Arguments
- regime
a column identifying which spatial regime each element of id belongs
- id
a column identifying unique observations
- diag
default FALSE. If TRUE, includes diagonal element / the self.
Value
An object of class nb. When diag = TRUE the attribute self.included = TRUE.
Examples
id <- guerry$code_dept
regime <- guerry$region
st_block_nb(regime, id)
#> Neighbour list object:
#> Number of regions: 85
#> Number of nonzero links: 1360
#> Percentage nonzero weights: 18.82353
#> Average number of links: 16
#> 5 disjoint connected subgraphs