Given geometry and a neighbor list, creates an sf object to be used as nodes in an sfnetworks::sfnetwork(). If the provided geometry is a polygon, sf::st_point_on_surface() will be used to create the node point.
Usage
st_as_nodes(x, nb)
# S3 method for class 'sf'
st_as_nodes(x, nb)
# S3 method for class 'sfc'
st_as_nodes(x, nb)Arguments
- x
object of class
sforsfc.- nb
a neighbor list. If
xis classsf, the unquote named of the column. Ifxis classsfc, an object of classnbas created fromst_contiguity().
Details
st_as_node() adds a row i based on the attribute "region.id" in the nb object. If the nb object is created with sfdep, then the values will always be row indexes.
Examples
if (requireNamespace("dplyr", quitly = TRUE)) {
library(magrittr)
guerry %>%
dplyr::transmute(nb = st_contiguity(geometry)) %>%
st_as_nodes(nb)
}